@@ -15,6 +15,7 @@ try:
     import torch
     from torch import nn
     from torch import optim
+    from torch.utils import data
     from ignite import engine
     from ignite import metrics
 except ImportError as ie:
@@ -36,6 +37,12 @@ class TrainTask(Task, metaclass=ABCMeta):
     your development.
     """
 
+    def __init__(self, prefix: Text = None):
+        if prefix is not None:
+            self.PROVIDE_KEY = f'{prefix}_model'
+        else:
+            self.PROVIDE_KEY = 'model'
+
     def invoke(self, profile: Profile, shared: Storage, logger: Logger) -> int:
         train_loader = shared['train_loader']
         validate_loader = shared['validate_loader']
@@ -55,16 +62,16 @@ class TrainTask(Task, metaclass=ABCMeta):
         self.more_metrics(metrics_dict)
 
         def prepare_batch(batch, device=None, non_blocking=False):
-            return deepcopy(self.prepare_batch(deepcopy(batch), device, non_blocking))
+            return self.prepare_batch(deepcopy(batch), device, non_blocking)
 
-        trainer = engine.create_supervised_trainer(
+        trainer = self.create_trainer(
             model, optimizer, loss,
             device=torch.device(profile.device),
             non_blocking=profile.non_blocking,
             prepare_batch=prepare_batch,
         )
 
-        evaluator = engine.create_supervised_evaluator(
+        evaluator = self.create_evaluator(
             model, metrics_dict,
             device=torch.device(profile.device),
             non_blocking=profile.non_blocking,
@@ -102,7 +109,7 @@ class TrainTask(Task, metaclass=ABCMeta):
             train_loader,
             max_epochs=profile.max_epochs
         )
-        shared['model'] = model
+        shared[self.PROVIDE_KEY] = model
         return Return.SUCCESS.value
 
     def require(self) -> List[Text]:
@@ -121,7 +128,7 @@ class TrainTask(Task, metaclass=ABCMeta):
         Returns:
             "model"
         """
-        return ['model']
+        return [self.PROVIDE_KEY]
 
     def remove(self) -> List[Text]:
         """
@@ -149,9 +156,6 @@ class TrainTask(Task, metaclass=ABCMeta):
         [loss]
         # You must implement define_optimizer to define the profile of the loss function.
         ```
-
-        Returns:
-
         """
         return [
             value('model', list, cls.define_model()),
@@ -291,7 +295,8 @@ class TrainTask(Task, metaclass=ABCMeta):
         """
         pass
 
-    def on_epoch_completed(self, engine_: engine.Engine, metrics_: Dict[Text, Any], profile: Profile, shared: Storage, logger: Logger):
+    def on_epoch_completed(self, engine_: engine.Engine, metrics_: Dict[Text, Any], profile: Profile, shared: Storage,
+                           logger: Logger):
         """
         Define the actions when an epoch completed.
 
@@ -367,12 +372,26 @@ class TrainTask(Task, metaclass=ABCMeta):
         """
         pass
 
+    def create_trainer(
+            self, model, optimizer, loss_fn, device, non_blocking, prepare_batch, output_transform=lambda x, y, y_pred, loss: loss.item()
+    ):
+        return engine.create_supervised_trainer(
+            model, optimizer, loss_fn, device, non_blocking, prepare_batch, output_transform
+        )
+
+    def create_evaluator(
+            self, model, metrics, device, non_blocking, prepare_batch, output_transform=lambda x, y, y_pred: (y_pred, y,)
+    ):
+        return engine.create_supervised_evaluator(
+            model, metrics, device, non_blocking, prepare_batch, output_transform
+        )
+
 
 class SimpleTrainTask(TrainTask, metaclass=ABCMeta):
     """
     <b>waterch.tasker.tasks.torch.SimpleTrainTask</b>
 
-    A easy to use base class of task for training models. You don't need to modify the code
+    An easy to use base class of task for training models. You don't need to modify the code
     to create optimizer and loss function, instead, you only need to implement the model.
     """
 
@@ -455,7 +474,7 @@ class SimpleTrainTask(TrainTask, metaclass=ABCMeta):
         """
         logger.info(f'EPOCH {engine_.state.epoch} | ' + ' | '.join(
             map(
-                lambda it: ': '.join(it),
+                lambda it: f'{it[0]}: {it[1]}',
                 metrics_.items()
             )
         ))
@@ -467,4 +486,176 @@ class SimpleTrainTask(TrainTask, metaclass=ABCMeta):
         epoch_iteration = engine_.state.iteration % engine_.state.epoch_length
         if epoch_iteration == 0:
             epoch_iteration = engine_.state.epoch_length
-        logger.info(f'ITERATION {epoch_iteration} | output: {engine_.state.output}')
+        logger.debug(f'ITERATION {epoch_iteration} | output: {engine_.state.output}')
+
+
+class DataLoaderTask(Task):
+    """
+    <b>waterch.tasker.tasks.torch.DataLoaderTask</b>
+
+    The fundamental task construction to provide data loaders.
+
+    Please declare the prefix of data loader in shared storage in reference
+    field of meta definitions.
+
+    Examples:
+        ```toml
+        # Data loader of validation.
+        [[__meta__]]
+        reference = "cifar_loader.CIFARDataLoaderTask:validate"
+        include = false
+        path = ""
+        profile = "validate_loader"
+        execute = true
+
+        # Data Loader of training.
+        [[__meta__]]
+        reference = "conv_train.ConvTrainTask:train"
+        include = false
+        path = ""
+        profile = "train"
+        execute = true
+        ```
+    """
+
+    def __init__(self, _type: Text = None):
+        if _type is None:
+            self.PROVIDE_KEY = 'loader'
+        else:
+            self.PROVIDE_KEY = f'{_type}_loader'
+
+    def invoke(self, profile: Profile, shared: Storage, logger: Logger) -> int:
+        dataset = self.create_dataset(profile.dataset, shared, logger)
+
+        assert isinstance(dataset, data.Dataset)
+
+        loader_params = dict(profile.loader)
+        loader_params['dataset'] = dataset
+
+        assert profile.sampler_type in ('sampler', 'batch_sampler', 'none')
+
+        if profile.sampler_type != 'none':
+            loader_params[profile.sampler_type] = self.create_sampler(
+                dataset, profile.sampler_type == 'batch_sampler', profile.sampler,
+                shared, logger
+            )
+
+        shared[self.PROVIDE_KEY] = data.DataLoader(**loader_params)
+        return Return.SUCCESS.value
+
+    def require(self) -> List[Text]:
+        return []
+
+    def provide(self) -> List[Text]:
+        return [self.PROVIDE_KEY]
+
+    def remove(self) -> List[Text]:
+        return []
+
+    @classmethod
+    def define(cls) -> List[Definition]:
+        """
+        ```toml
+        __schema__ = "waterch.tasker.tasks.torch.DataLoaderTask"
+        sampler_type = ""
+
+        [loader]
+        batch_size = 0
+        shuffle = true
+        num_workers = 0
+        pin_memory = true
+        drop_last = true
+        ```
+        """
+        return [
+            value('dataset', list, cls.define_dataset()),
+            value('loader', list, [
+                value('batch_size', int),
+                value('shuffle', bool),
+                value('num_workers', int),
+                value('pin_memory', bool),
+                value('drop_last', bool),
+            ]),
+            value('sampler_type', str),
+            value('sampler', list, cls.define_sampler())
+        ]
+
+    @abstractmethod
+    def create_dataset(self, profile: Profile, shared: Storage, logger: Logger) -> data.Dataset:
+        """
+        The function to create dataset instance with defined profile.
+
+        Args:
+            profile: Runtime profile defined in TOML file of dataset.
+            shared: Shared storage in the whole lifecycle.
+            logger: The logger named with this Task.
+
+        Returns:
+            A new dataset instance.
+        """
+        raise NotImplementedError('Please create the dataset in create_dataset')
+
+    @classmethod
+    @abstractmethod
+    def define_dataset(cls):
+        """
+        A profile template of dataset need to be implemented by user.
+
+        Returns:
+            Definition of dataset profile.
+        """
+        raise NotImplementedError('Please define the dataset profile in define_dataset')
+
+    @abstractmethod
+    def create_sampler(self, dataset: data.Dataset, batch_sampler: bool, profile: Profile, shared: Storage,
+                       logger: Logger):
+        """
+        The function to create sampler instance with defined profile.
+
+        Args:
+            dataset: The dataset instance need to be loaded.
+            batch_sampler: Whether to use batch_sampler.
+            profile: Runtime profile defined in TOML file of sampler or batch sampler.
+            shared: Shared storage in the whole lifecycle.
+            logger: The logger named with this Task.
+
+        Returns:
+            A new sampler or batch sampler instance.
+        """
+        if batch_sampler:
+            raise NotImplementedError('Please create the batch sampler in create_sampler')
+        else:
+            raise NotImplementedError('Please create the sampler in create_sampler')
+
+    @classmethod
+    @abstractmethod
+    def define_sampler(cls):
+        raise NotImplementedError('Please define the sampler or batch sampler profile in define_sampler')
+
+
+class SimpleDataLoaderTask(DataLoaderTask):
+    """
+    <b>waterch.tasker.tasks.torch.SimpleDataLoaderTask</b>
+
+    An easy to use base class of task for providing data loader. You can
+    create data loader only with reference of dataset and related profile.
+    """
+
+    def create_dataset(self, profile: Profile, shared: Storage, logger: Logger) -> data.Dataset:
+        dataset_cls = import_reference(profile.reference)
+        return dataset_cls(**profile.kwargs)
+
+    @classmethod
+    def define_dataset(cls):
+        return [
+            value('reference', str),
+            value('kwargs', list, [])
+        ]
+
+    def create_sampler(self, dataset: data.Dataset, batch_sampler: bool, profile: Profile, shared: Storage,
+                       logger: Logger):
+        return None
+
+    @classmethod
+    def define_sampler(cls):
+        return []
